@@ -2,7 +2,7 @@
 #of this repository contains the full copyright notices and license terms.
 "Currency"
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.tools import safe_eval
+from trytond.tools import safe_eval, datetime_strftime
 import time
 from decimal import Decimal, ROUND_HALF_EVEN
 import datetime
@@ -15,8 +15,9 @@ class Currency(ModelSQL, ModelView):
     name = fields.Char('Name', required=True, translate=True)
     symbol = fields.Char('Symbol', size=10, required=True)
     code = fields.Char('Code', size=3, required=True)
-    rate = fields.Function('get_rate', type='numeric', string='Current rate',
-            digits=(12, 6), on_change_with=['rates'])
+    numeric_code = fields.Char('Numeric Code', size=3)
+    rate = fields.Function(fields.Numeric('Current rate', digits=(12, 6),
+        on_change_with=['rates']), 'get_rate')
     rates = fields.One2Many('currency.currency.rate', 'currency', 'Rates')
     rounding = fields.Numeric('Rounding factor', digits=(12, 6), required=True)
     digits = fields.Integer('Display Digits')
@@ -108,20 +109,19 @@ class Currency(ModelSQL, ModelView):
     def check_xml_record(self, cursor, user, ids, values, context=None):
         return True
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [('code', args[i][1], args[i][2])],
-                    limit=1, context=context)
-            if len(ids):
-                args2.append(('code', args[i][1], args[i][2]))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = []
+        field = None
+        for field in ('code', 'numeric_code'):
+            ids = self.search(cursor, user, [(field,) + clause[1:]], limit=1,
+                    context=context)
+            if ids:
+                break
+        if ids:
+            return [(field,) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
-    def on_change_with_rate(self, cursor, user, ids, vals, context=None):
+    def on_change_with_rate(self, cursor, user, vals, context=None):
         now = datetime.date.today()
         closer = datetime.date.min
         res = Decimal('0.0')
@@ -133,7 +133,7 @@ class Currency(ModelSQL, ModelView):
                 closer = rate['date']
         return res
 
-    def get_rate(self, cursor, user, ids, name, arg, context=None):
+    def get_rate(self, cursor, user, ids, name, context=None):
         '''
         Return the rate at the date from the context or the current date
         '''
@@ -220,7 +220,7 @@ class Currency(ModelSQL, ModelView):
             lang = lang_obj.browse(cursor, user, lang_ids[0], context=context)
 
             self.raise_user_error(cursor, 'no_rate', (name,
-                date.strftime(str(lang.date))), context=context)
+                datetime_strftime(date, str(lang.date))), context=context)
         if round:
             return self.round(cursor, user, to_currency,
                     amount * to_currency.rate / from_currency.rate)
